@@ -435,7 +435,7 @@ namespace apg {
             write_macrocell_headerless(outstream, hnode, rule, multistate);
         }
 
-        hypernode<I> read_macrocell(std::istream &instream, std::string &rule) {
+        hypernode<I> read_macrocell(std::istream &instream, std::string &rule, std::vector<hypernode<I> > *framevec) {
             /*
             * Returns a hypernode representing the contents of a macrocell
             * file. This handles both 2- and n-state macrocell files using the
@@ -486,6 +486,15 @@ namespace apg {
                         if ((line.length() >= 20) && (line.substr(0, 20) == "#CLL state-numbering")) {
                             golly_numbering = (line.find("golly") != std::string::npos) ? 3 : 0;
                         }
+                    } else if ((line.length() > 7) && (line.substr(0, 7) == "#FRAME ") && (framevec != 0)) {
+                        std::stringstream s(line.substr(7));
+                        uint64_t frameidx;
+                        uint64_t frameloc;
+                        s >> frameidx >> frameloc;
+                        if (framevec->size() <= frameidx) {
+                            framevec->resize(frameidx + 1);
+                        }
+                        framevec->at(frameidx) = hypernode<I>(pleaves[frameloc].x[0], pleaves[frameloc].x[1] - 4);
                     } else {
                         // line is a comment
                     }
@@ -562,6 +571,7 @@ namespace apg {
                             }
                             lastnode = make_leaf(leaf);
                             pleaf.x[0] = lastnode;
+                            pleaf.x[1] = log2size;
                         } else {
                             // Nonleaf:
                             I tl = pleaves[a].x[0];
@@ -571,6 +581,7 @@ namespace apg {
                             nicearray<I, 4> nonleaf = {tl, tr, bl, br};
                             lastnode = make_nonleaf(log2size - 4, nonleaf);
                             pleaf.x[0] = lastnode;
+                            pleaf.x[1] = log2size;
                         }
                     } else {
                         std::cerr << "Invalid line: " << line << std::endl;
