@@ -497,11 +497,15 @@ namespace apg {
             return shift_universe(hn, nx, ny, 0);
         }
 
-        virtual hypernode<I> read_macrocell(std::istream &instream, std::string &rule) = 0;
+        virtual hypernode<I> read_macrocell(std::istream &instream, std::string &rule, std::vector<hypernode<I> > *frames) = 0;
+
+        hypernode<I> load_macrocell(std::string filename, std::string &rule, std::vector<hypernode<I> > *frames) {
+            std::ifstream f(filename);
+            return read_macrocell(f, rule, frames);
+        }
 
         hypernode<I> load_macrocell(std::string filename, std::string &rule) {
-            std::ifstream f(filename);
-            return read_macrocell(f, rule);
+            return load_macrocell(filename, rule, 0);
         }
 
         hypernode<I> load_macrocell(std::string filename, std::string &rule, int64_t x, int64_t y) {
