@@ -30,6 +30,7 @@ class Pattern(object):
         self.lifelib = session.lifelib
         self.session = session
         self.owner = owner
+        self.comments = []
 
         session.pattern_ptrs.add(ptr)
 
@@ -422,7 +423,7 @@ class Pattern(object):
             print("Oscillation not detected (try increasing maxexp?)")
         return {}
 
-    def write_rle(self, filename, header=None, footer=None, comments=None, file_format='rle'):
+    def write_rle(self, filename, header=None, footer=None, comments=None, file_format='rle', save_comments=True):
 
         filename = os.path.abspath(filename)
 
@@ -432,10 +433,13 @@ class Pattern(object):
         if footer is None:
             footer = ''
 
-        if comments is not None:
+        if save_comments:
+            if comments is None:
+                comments = self.comments
             if hasattr(comments, 'splitlines'):
                 comments = comments.splitlines()
-            header = header + ''.join([('#C %s\n' % x) for x in comments])
+            comments = [(x if x.startswith('#C ') else ('#C ' + x)) for x in comments]
+            header += ''.join([('%s\n' % x) for x in comments])
 
         llc = 'SavePatternRLE' if (file_format[-3:].lower() == 'rle') else 'SavePatternMC'
         self.lifelib(llc, self.ptr, filename, header, footer)
