@@ -162,6 +162,27 @@ $.4B$4B$3B$2B!'''
 
         self.assertEqual(coe.wechsler, 'gcbgzvgg826frc')
 
+    def test_timeline(self):
+
+        try:
+            os.makedirs('lifelib/tempdir')
+        except:
+            pass
+
+        try:
+            lidka = self.lt.pattern("bo$obo$bo8$8bo$6bobo$5b2obo2$4b3o!")
+            lframes = [lidka[i << 8] for i in range(120)]
+            self.lt.save_timeline(lframes, 'lifelib/tempdir/timeline.mc')
+            frames2 = self.lt.load('lifelib/tempdir/timeline.mc')
+
+            self.assertEqual(len(lframes), len(frames2))
+            for (x, y) in zip(lframes, frames2):
+                self.assertEqual(x, y)
+
+        finally:
+            import shutil
+            shutil.rmtree('lifelib/tempdir')
+
     def test_io(self):
 
         try:
